@@ -14,6 +14,7 @@
 #include <fcntl.h> //we check some files
 #include <unistd.h>  //closing file
 
+#include "../../cem/cem.h"
 
 #include "../../meam/jammo-backing-track.h"
 #include "../../meam/jammo-recording-track.h"
@@ -262,6 +263,10 @@ static gboolean song_icon_clicked(TangleButton* tanglebutton, gpointer data){
 	printf("image_filename = '%s'\n",image_filename);
 
 	ClutterActor *texture = clutter_texture_new_from_file(image_filename, NULL);
+	if (!texture) {
+		texture = clutter_texture_new_from_file("/opt/jammo/nopic.png", NULL);
+	}
+
 	clutter_container_add(CLUTTER_CONTAINER(view), texture, NULL);
 	g_free(image_filename);
 
@@ -467,11 +472,11 @@ static void icon_offset_from_json(char* filename, gfloat* x,gfloat* y, gfloat* w
   parser = json_parser_new ();
   g_assert (JSON_IS_PARSER (parser));
 
-  GError *error = NULL;
-  if (!json_parser_load_from_file (parser, filename, &error))
+  if (!json_parser_load_from_file (parser, filename, NULL))
         {
-          g_print ("Error: %s\n", error->message);
-          g_error_free (error);
+          gchar* message = g_strdup_printf("Can't load file '%s' for json-parsing. Using default values",filename);
+          cem_add_to_log(message,LOG_WARN);
+          g_free(message);
           g_object_unref (parser);
           return;
         }
@@ -536,8 +541,15 @@ void song_prepare_icon(jammo_song* song){
 	song->x_size = x_size;
 	song->y_size = y_size;
 
-	ClutterActor* texture = clutter_texture_new_from_file(image_filename, NULL);
-	ClutterActor* interactive_texture = clutter_texture_new_from_file(image_filename, NULL);
+	ClutterActor* texture;
+	ClutterActor* interactive_texture;
+	texture = clutter_texture_new_from_file(image_filename, NULL);
+	if (texture) {
+		interactive_texture = clutter_texture_new_from_file(image_filename, NULL);
+	} else {
+		texture = clutter_texture_new_from_file("/opt/jammo/nopic.png", NULL);
+		interactive_texture = clutter_texture_new_from_file("/opt/jammo/nopic.png", NULL);
+		}
 	clutter_actor_set_opacity(interactive_texture, 40.0); //This could be fancier effect.
 	ClutterActor* songbutton = tangle_button_new_with_background_actors(texture,interactive_texture);
 	song->songbutton = songbutton;
