@@ -239,6 +239,53 @@ static samplebutton_tuple melodics[] = {
 	{"wheel_game/cello.png", "wheel_game/Me_cello01_$t_$p_44_2.ogg"},
 	{"wheel_game/cello.png", "wheel_game/Me_cello02_$t_$p_44_1.ogg"},
 	{"wheel_game/cello.png", "wheel_game/Me_cello05_$t_$p_44_1.ogg"},
+	{"wheel_game/double_bass.png", "wheel_game/Me_doublebass01_$t_$p_44_1.ogg"},
+	{"wheel_game/double_bass.png", "wheel_game/Me_doublebass02_$t_$p_44_1.ogg"},
+	{"wheel_game/double_bass.png", "wheel_game/Me_doublebass03_$t_$p_44_1.ogg"},
+	{"wheel_game/double_bass.png", "wheel_game/Me_doublebass04_$t_$p_44_1.ogg"},
+	{"wheel_game/harp.png", "wheel_game/Me_harp01_$t_$p_34_2.ogg"},
+	{"wheel_game/harp.png", "wheel_game/Me_harp02_$t_$p_44_2.ogg"},
+	{"wheel_game/harp.png", "wheel_game/Me_harp03_$t_$p_44_2.ogg"},
+	{"wheel_game/harp.png", "wheel_game/Me_harp04_$t_$p_44_2.ogg"},
+	{"wheel_game/harp.png", "wheel_game/Me_harp05_$t_$p_34_2.ogg"},
+	{"wheel_game/mandolin.png", "wheel_game/Me_mandolin02_$t_$p_34_4.ogg"},
+	{"wheel_game/saxophone.png", "wheel_game/Me_sax01_$t_$p_44_1.ogg"},
+	{"wheel_game/saxophone.png", "wheel_game/Me_sax02_$t_$p_44_1.ogg"},
+	{"wheel_game/saxophone.png", "wheel_game/Me_sax03_$t_$p_44_1.ogg"},
+	{"wheel_game/saxophone.png", "wheel_game/Me_sax04_$t_$p_44_1.ogg"},
+	{"wheel_game/saxophone.png", "wheel_game/Me_sax05_$t_$p_44_2.ogg"},
+	{"wheel_game/saxophone.png", "wheel_game/Me_sax06_$t_$p_44_2.ogg"},
+	{"wheel_game/saxophone.png", "wheel_game/Me_sax07_$t_$p_44_1.ogg"},
+	{"wheel_game/saxophone.png", "wheel_game/Me_sax08_$t_$p_44_2.ogg"},
+	{"wheel_game/saxophone.png", "wheel_game/Me_sax09_$t_$p_44_2.ogg"},
+	{"wheel_game/saxophone.png", "wheel_game/Me_sax10_$t_$p_44_1.ogg"},
+	{"wheel_game/saxophone.png", "wheel_game/Me_sax11_$t_$p_44_2.ogg"},
+	{"wheel_game/saxophone.png", "wheel_game/Me_sax12_$t_$p_44_2.ogg"},
+	{"wheel_game/saxophone.png", "wheel_game/Me_ScarboroughFairSax_$t_$p_44_8.ogg"},
+	{"wheel_game/saxophone.png", "wheel_game/Me_SiyaHambaSax1_$t_$p_44_4.ogg"},
+	{"wheel_game/oboe.png", "wheel_game/Me_oboe01_$t_$p_44_2.ogg"},
+	{"wheel_game/oboe.png", "wheel_game/Me_oboe02_$t_$p_44_1.ogg"},
+	{"wheel_game/oboe.png", "wheel_game/Me_oboe03_$t_$p_44_2.ogg"},
+	{"wheel_game/oboe.png", "wheel_game/Me_oboe04_$t_$p_44_1.ogg"},
+	{"wheel_game/oboe.png", "wheel_game/Me_oboe05_$t_$p_34_2.ogg"},
+	{"wheel_game/oboe.png", "wheel_game/Me_oboe06_$t_$p_44_1.ogg"},
+	{"wheel_game/oboe.png", "wheel_game/Me_oboe07_$t_$p_34_2.ogg"},
+	{"wheel_game/oboe.png", "wheel_game/Me_oboe08_$t_$p_34_2.ogg"},
+	{"wheel_game/organ.png", "wheel_game/Me_LatinOrgan1_$t_$p_44_2.ogg"},
+	{"wheel_game/organ.png", "wheel_game/Me_organ3_$t_$p_44_2.ogg"},
+	{"wheel_game/organ.png", "wheel_game/Me_organ4_$t_$p_44_2.ogg"},
+	{"wheel_game/organ.png", "wheel_game/Me_organ5_$t_$p_44_2.ogg"},
+	{"wheel_game/organ.png", "wheel_game/Me_organ6_$t_$p_44_2.ogg"},
+	{"wheel_game/vibraphone.png", "wheel_game/Me_vibraphone01_$t_$p_34_2.ogg"},
+	{"wheel_game/trombone.png", "wheel_game/Me_trombone01_$t_$p_44_1.ogg"},
+	{"wheel_game/trombone.png", "wheel_game/Me_trombone02_$t_$p_44_1.ogg"},
+	{"wheel_game/trombone.png", "wheel_game/Me_trombone03_$t_$p_44_2.ogg"},
+	{"wheel_game/trombone.png", "wheel_game/Me_trombone04_$t_$p_44_1.ogg"},
+	{"wheel_game/trombone.png", "wheel_game/Me_trombone05_$t_$p_44_1.ogg"},
+	{"wheel_game/trombone.png", "wheel_game/Me_trombone06_$t_$p_44_2.ogg"},
+	{"wheel_game/trombone.png", "wheel_game/Me_trombone07_$t_$p_44_1.ogg"},
+	{"wheel_game/trombone.png", "wheel_game/Me_trombone08_$t_$p_44_1.ogg"},
+	{"wheel_game/trombone.png", "wheel_game/Me_trombone09_$t_$p_44_1.ogg"},
 	{NULL,NULL}
 };
 
@@ -257,6 +304,16 @@ static samplebutton_tuple harmonics[] = {
 	{"wheel_game/banjo.png", "wheel_game/Ha_banjo02_$t_$p_44_1.ogg"},
 	{"wheel_game/cello.png", "wheel_game/Ha_cello04_$t_$p_44_1.ogg"},
 	{"wheel_game/cello.png", "wheel_game/Ha_cello09_$t_$p_44_1.ogg"},
+	{"wheel_game/mandolin.png", "wheel_game/Ha_mandolin01_$t_$p_44_1.ogg"},
+	{"wheel_game/organ.png", "wheel_game/Ha_organ01_$t_$p_44_2.ogg"},
+	{"wheel_game/organ.png", "wheel_game/Ha_organ02_$t_$p_44_2.ogg"},
+	{"wheel_game/organ.png", "wheel_game/Ha_organ07_$t_$p_44_1.ogg"},
+	{"wheel_game/organ.png", "wheel_game/Ha_organ08_$t_$p_44_1.ogg"},
+	{"wheel_game/organ.png", "wheel_game/Ha_organ09_$t_$p_44_1.ogg"},
+	{"wheel_game/organ.png", "wheel_game/Ha_organ10_$t_$p_44_1.ogg"},
+	{"wheel_game/organ.png", "wheel_game/Ha_organ11_$t_$p_44_2.ogg"},
+	{"wheel_game/organ.png", "wheel_game/Ha_organ12_$t_$p_44_2.ogg"},
+	{"wheel_game/trumpet.png", "wheel_game/Ha_trumpet01_$t_$p_44_2.ogg"},
 	{NULL,NULL}
 };
 
@@ -294,6 +351,8 @@ static int add_sample_buttons(ClutterActor* looper, samplebutton_tuple table[],
 		jammo_sample_button_set_image_filename(JAMMO_SAMPLE_BUTTON(sample_button),full_image);
 		jammo_sample_button_set_sample_filename(JAMMO_SAMPLE_BUTTON(sample_button), full_sound);
 
+		g_object_set(sample_button,"drag-threshold-y",10000,NULL); //No dragging by vertical-axis (it is for scrolling wheel)
+
 		jammo_sample_button_set_loop_id(JAMMO_SAMPLE_BUTTON(sample_button), counter+loop_type);
 		g_free(full_image);
 		g_free(full_sound);
