@@ -19,7 +19,7 @@ And then sequencer_track_view_add_with_type(sequencerTrackViewTYpe)
 #include "../../meam/jammo-midi.h"
 #include "../../meam/jammo-meam.h" //JAMMO_DURATION_INVALID
 
-#include "../jammo-track-view.h"
+#include "../jammo-editing-track-view.h"
 #include "../jammo-miditrack-view.h"
 #include "../jammo.h"
 #include "../jammo-cursor.h"
@@ -164,7 +164,7 @@ ClutterActor* sequencer_track_view_add_backing_track(JammoTrack* track, gboolean
 
 /*
  * Adds given type of track view into sequencer view
- * Returns track_view_actor (jammo_track_view) of newly created sequencer_track_view
+ * Returns track_view_actor (jammo_editing_track_view) of newly created sequencer_track_view
  * Returns NULL is askes invalid type.
  */
 ClutterActor* sequencer_track_view_add_with_type(gint track_view_type, gboolean muted, gfloat volume, gint optional_parameter) {
@@ -264,7 +264,7 @@ ClutterActor* sequencer_track_view_add_with_type(gint track_view_type, gboolean
 	{
 		track = JAMMO_TRACK(jammo_editing_track_new_fixed_duration(duration_of_tracks));
 
-		track_view_actor = jammo_track_view_new(JAMMO_EDITING_TRACK(track),
+		track_view_actor = jammo_editing_track_view_new(JAMMO_EDITING_TRACK(track),
           number_of_slots, duration_of_one_slot, width_of_slot, track_height);
 		clutter_actor_set_reactive(track_view_actor, TRUE);
 		g_object_set(track_view_actor, "line-every-nth-slot", 1, "sample-type", optional_parameter, NULL);
@@ -338,7 +338,7 @@ static gboolean pressed_sequencer_button_mute (TangleButton *tanglebutton, gpoin
 	JammoPlayingTrack* jammotrack;
 
 	//slider and backingtrack is inside tangle_widget, midi- and loop-tracks are inside of jammo-*track-view
-	if (JAMMO_IS_TRACK_VIEW(track_view->track_view) || JAMMO_IS_MIDITRACK_VIEW(track_view->track_view)) {
+	if (JAMMO_IS_EDITING_TRACK_VIEW(track_view->track_view) || JAMMO_IS_MIDITRACK_VIEW(track_view->track_view)) {
 		g_object_get(track_view->track_view, "track", &jammotrack, NULL);
 	} else if (TANGLE_IS_WIDGET(track_view->track_view)) {
 		jammotrack = JAMMO_PLAYING_TRACK(g_object_get_data(G_OBJECT(track_view->track_view),"track"));
@@ -406,7 +406,7 @@ static gboolean pressed_sequencer_button_volume (TangleButton *tanglebutton, gpo
 	JammoPlayingTrack* jammotrack;
 
 	//slider and backingtrack is inside tangle_widget, midi- and loop-tracks are inside of jammo-*track-view
-	if (JAMMO_IS_TRACK_VIEW(track_view->track_view) || JAMMO_IS_MIDITRACK_VIEW(track_view->track_view)) {
+	if (JAMMO_IS_EDITING_TRACK_VIEW(track_view->track_view) || JAMMO_IS_MIDITRACK_VIEW(track_view->track_view)) {
 		g_object_get(track_view->track_view, "track", &jammotrack, NULL);
 	} else if (TANGLE_IS_WIDGET(track_view->track_view)) {
 		jammotrack = JAMMO_PLAYING_TRACK(g_object_get_data(G_OBJECT(track_view->track_view),"track"));
