@@ -25,12 +25,12 @@
 typedef struct _JammoSampleButtonPrivate JammoSampleButtonPrivate;
 
 typedef struct _JammoSampleButton {
-	TangleDraggableActor parent_instance;
+	TangleButton parent_instance;
 	JammoSampleButtonPrivate* priv;
 } JammoSampleButton;
 
 typedef struct _JammoSampleButtonClass {
-	TangleDraggableActorClass parent_class;
+	TangleButtonClass parent_class;
 } JammoSampleButtonClass;
 
 GType jammo_sample_button_get_type(void) G_GNUC_CONST;
