@@ -6,11 +6,12 @@
 
 int *get_user_passwd()
 {
-	//Should read passwords from profiler
+	//Should read passwords as strings from profiler
+
 
 	int user_id;
 	gchar *username="Guest";
-	gchar *passworddata="passworddata";
+	gchar *passworddata="password";
 	gint dummy_login;
 	user_id = gems_profile_manager_get_userid(NULL);
 	dummy_login=gems_profile_manager_login(user_id, username,passworddata);
