@@ -856,7 +856,7 @@ static void gst_jammo_slider_process_##type (GstJammoSlider * src, g##type * sam
 	if (src->freq!=src->last_reported_frequency) {\
 		src->last_reported_frequency=src->freq; \
 		GstStructure *s;\
-		s = gst_structure_new ("slider", "frequency", G_TYPE_FLOAT, src->freq, NULL);\
+		s = gst_structure_new ("slider", "frequency", G_TYPE_FLOAT, src->freq * pitch(-src->pitch_shift), NULL);\
 \
 		GstMessage *m = gst_message_new_element (GST_OBJECT (src), s);\
 		gst_element_post_message (GST_ELEMENT (src), m);\
